CalculatorService

Struct CalculatorService 

pub struct CalculatorService;
CalculatorService wraps Calculator for Cordis dependency injection.

Service provides the feature gate boundary. Tool implements the same arithmetic logic as Calculator without any behavior change.

Implementations

Source

impl CalculatorService

pub fn new() -> CalculatorService

Create with default config.

pub fn with_config(_config: CalculatorConfig) -> CalculatorService

Create from explicit config. Config is currently empty and kept for Plugin compatibility.